import { defHttp } from '/@/utils/http/axios'
import {
  LoginParams,
  // LoginResultModel,
  GetUserInfoByUserIdParams,
  GetUserInfoByUserIdModel
} from './model/userModel'

import { ErrorMessageMode } from '/@/utils/http/axios/types'

enum Api {
  Login = '/backstage/login',
  Logout = '/backstage/out',
  GetUserInfoById = '/login/project/name',
  GetPermCodeByUserId = '/getPermCodeByUserId',
  GetToken = '/login/project/name'
}

/**
 * @description: user login api
 */
export function loginApi(params: LoginParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<GetUserInfoByUserIdModel>(
    {
      url: Api.Login,
      params
    },
    {
      errorMessageMode: mode
    }
  )
}

/**
 * @description: getUserInfoById
 */
export function getUserInfoById(params: GetUserInfoByUserIdParams) {
  return defHttp.get<GetUserInfoByUserIdModel>({
    url: Api.GetUserInfoById,
    params
  })
}

export function getPermCodeByUserId(params: GetUserInfoByUserIdParams) {
  return defHttp.get<string[]>({
    url: Api.GetPermCodeByUserId,
    params
  })
}

export function getXsrfToken(code: string) {
  return defHttp.get({
    url: Api.GetToken,
    params: { code }
  })
}

export function logoutApi() {
  return defHttp.post({
    url: Api.Logout
  })
}
